// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import MapKit
import GMAppData

struct AppointmentDetailView: View, ScreenTrackable {
    @ObservedObject var viewModel: ViewModel
    
    init(activity: Activity) {
        viewModel = ViewModel(activity: activity)
    }
    
    var body: some View {
        ScrollView(viewModel.state.scrollAxis) {
            if let activity = viewModel.activity {
                VStack(alignment: .leading, spacing: 0) {
                    VStack(alignment: .leading) {
                        AppointmentDetailTitleHeader(
                            title: activity.title,
                            subtitle: viewModel.subtitle
                        )
                        .padding(.bottom, 16)
                    }
                    .padding()
                    .background(R.color.viewBackground.color())
                    BottomContainerCardView {
                        VStack {
                            AppointmentDetailsDescriptionView(description: activity.description)
                            Spacer(minLength: 0)
                        }
                        .padding([.horizontal, .bottom])
                    }
                }
            } else {
                EmptyStateView(
                    title: Localizable.common_alert_title_error(),
                    text: Localizable.common_alert_message_generic()
                )
            }
        }
        .navigationBarTitle(Text(Localizable.appointment_details_title()), displayMode: .inline)
        .background(R.color.cardBackground.color())
        .protectedAppearanceEvents(
            onAppear: {
                viewModel.fetchDictionary()
            })
        .screenTracking(screenTrackingName)
    }
}

#if DEBUG
struct AppointmentDetailView_Previews: PreviewProvider {
    static var previews: some View {
        AppointmentDetailView(
            activity: loadPreviewCarePlan()
                .activities!
                .first!
        ).environment(\.colorScheme, .light)
        
        AppointmentDetailView(
            activity: loadPreviewCarePlan()
                .activities!
                .statusSetForWeek(7)
                .planned
                .first!
        ).environment(\.colorScheme, .dark)
    }
}
#endif
