// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import GMAppData

struct ActivitiesTimeline: View {
    let entryPrefix: String
    let activities: [Activity]
    let backgroundColor: Color
    let lineColor: Color
    let topSpace: CGFloat

    private let cardSpacing: CGFloat = 8

    var body: some View {
        CompatibleVStack(spacing: 0) {
            ForEach(activities) { activity in
                let index: Int? = activities.firstIndex(where: { $0 == activity })
                let topPadding: CGFloat = index == 0 ? topSpace : cardSpacing
                
                ActivityTimelineEntryView(
                    lineColor: lineColor,
                    dotColor: activity.dotColor,
                    topPadding: topPadding,
                    content: {
                        ActivityEntryCardView(
                            activity: activity
                        )
                    }
                )
                .id("\(entryPrefix)_\(activity.description)")
                
            }
        }
        .background(backgroundColor)
    }
}
    
#if DEBUG
    struct ActivitiesTimeline_Previews: PreviewProvider {
        static var previews: some View {
            ScrollView {
                VStack(spacing: 0) {
                    ActivitiesTimeline(
                        entryPrefix: "1",
                        activities: [loadPreviewCarePlan().activities!.first!],
                        backgroundColor: .gray,
                        lineColor: .pink,
                        topSpace: 20
                    )
                    ActivitiesTimeline(
                        entryPrefix: "2",
                        activities: loadPreviewCarePlan().activities!,
                        backgroundColor: .white,
                        lineColor: .pink,
                        topSpace: 20
                    )
                }
            }
        }
    }
#endif
