// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import Combine
import ErrorData

struct ChecklistDetailItemList: View {
    @State private var isEditing = false
    @State private var cancelBag = CancelBag()
    
    @State private var allowAnimations : Bool = false
    
    var checklist: Checklist
    
    var toggleItemEvent: (Checklist.Item) -> Void
    var deleteItemEvent: (Checklist.Item) -> Void
    var addItemEvent: (Checklist.Item) -> Void
    var updateItemEvent: (Checklist.Item) -> Void
    
    func checkedItems() -> [Checklist.Item] {
        checklist.items.filter { $0.isChecked }
    }
    
    func uncheckedItems() -> [Checklist.Item] {
        checklist.items.filter { !$0.isChecked }
    }
    
    var body: some View {
        VStack(alignment: .leading, spacing: Metrics.Spacing.narrowCardSpacing) {
            Text(Localizable.checklist_unchecked_items_title())
                .applyTextStyle(fontStyle: .h4)
            ForEach(uncheckedItems()) { item in
                ChecklistDetailItemRow(
                    item: item,
                    toggleItemEvent: toggleItemEvent,
                    deleteItemEvent: deleteItemEvent,
                    updateItemEvent: updateItemEvent
                )
            }
            
            if isEditing {
                ChecklistAddItemRow(addItemEvent: { item in
                    isEditing = false
                    addItemEvent(item)
                })
            }
            PrimaryButton(
                title: Localizable.checklist_add_item(checklist.title)) {
                    isEditing = true
                }
                .padding(.vertical)
                .padding(.bottom, 60)
            
            if !checkedItems().isEmpty {
                Text(Localizable.checklist_checked_items_title())
                    .applyTextStyle(fontStyle: .h4)
                ForEach(checkedItems()) { item in
                    ChecklistDetailItemRow(
                        item: item,
                        toggleItemEvent: toggleItemEvent,
                        deleteItemEvent: deleteItemEvent,
                        updateItemEvent: updateItemEvent
                    )
                }
            }
        }
        .animation(self.allowAnimations ? .default : nil)
            .onAppear {
                self.allowAnimations = true
            }
        .padding()
    }
}
