// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import Combine
import ErrorData
import CMSData

struct SettingsConsentPageView: View {
    @ObservedObject var viewModel: SettingsPageView.ViewModel

    var body: some View {
        VStack(spacing: 0) {
            SettingsPageView(viewModel: viewModel)
            BottomContainerCardView {
                PrimaryButton(
                    title: Localizable.settings_consent_remove_title(),
                    action: {
                        App.topViewController?.presentPartialSheet(
                            buttons: sheetButtons,
                            content: {
                                removeConsentSheet()
                            }
                        )
                    }
                )
                .padding()
            }
        }
        .alert(for: $viewModel.error)
    }

    @ViewBuilder
    private func removeConsentSheet() -> some View {
        VStack {
            HStack {
                Text(Localizable.settings_consent_remove_title())
                    .applyTextStyle(fontStyle: .h1)
                Spacer(minLength: 0)
            }
            .padding(.bottom)
            Text(Localizable.settings_consent_remove_description())
                .applyTextStyle(fontStyle: .body)
        }
    }

    private var sheetButtons: [PartialSheetButton] {
        [
            PartialSheetButton(
                title: Localizable.settings_consent_remove_title(),
                color: R.color.pinWrong.color(),
                action: {
                    viewModel.removeConsent()
                }
            ),
            PartialSheetButton(
                title: Localizable.common_regret(),
                color: R.color.primary.color(),
                action: nil
            )
        ]
    }
}

struct SettingsConsentPageView_Previews: PreviewProvider {
    static var previews: some View {
        SettingsConsentPageView(
            viewModel: SettingsPageView.ViewModel(
                title: "Test",
                pageFetcher: Just(
                    Page(
                        title: "Test",
                        content: "Test",
                        excerpt: nil,
                        slug: nil)
                )
                .setFailureType(to: ServiceError.self)
                .eraseToAnyPublisher()
            )
        )
    }
}
