// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OverviewHeaderDualValueCard: View {
    let title: String?
    let value1: String?
    let value2: String?
    let minWidth: CGFloat

    var body: some View {
        OverviewHeaderCard(title: title, minWidth: minWidth) {
            HStack(spacing: 4) {
                if let value1 = value1, let value2 = value2 {
                    Text(value1)
                        .applyTextStyle(fontStyle: .h1)
                        .fixedSize(horizontal: true, vertical: false)
                    Text(value2)
                        .applyTextStyle(fontStyle: .h5)
                        .fixedSize(horizontal: true, vertical: false)
                } else {
                    Text(Localizable.common_missing_data())
                        .applyTextStyle(fontStyle: .h1)
                        .accessibility(label: Text(Localizable.common_missing_data_accessibility_label()))
                }
            }
        }
        .accessibility(label: Text("\(title ?? ""): \(value1 ?? "") \(value2 ?? "")"))
    }
}

struct OverviewHeaderDualValueCard_Previews: PreviewProvider {
    static var previews: some View {
        OverviewHeaderDualValueCard(
            title: "Test",
            value1: "12",
            value2: "(12+3)",
            minWidth: 70
        )
    }
}
