// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import SharedServices

struct OverviewHeaderView: View {

    let monthsIntoPregnancy: Double?
    let numberOfFetuses: Int
    let title: String
    let subtitle: String?
    let controls: [OverviewHeaderControl]
    let titleButtonAction: (() -> Void)?

    @DI private var systemInformationService: SystemInformationService
    @State private var beginAnimation: Bool = false

    var body: some View {
        VStack(spacing: 16) {
            HStack(spacing: 0) {
                Spacer(minLength: 0)
                OverviewPregnancyProgressView(
                    monthsIntoPregnancy: monthsIntoPregnancy,
                    beginAnimation: beginAnimation,
                    numberOfFetuses: numberOfFetuses
                )
                .frame(size: 220)
                Spacer(minLength: 0)
            }
            HStack {
                VStack {
                    Text(title)
                        .applyTextStyle(fontStyle: .h4)
                    if let subtitle = subtitle {
                        Text(subtitle)
                            .applyTextStyle(fontStyle: .info)
                    }
                }
                if let action = titleButtonAction {
                    Button(
                        action: action,
                        label: {
                            Image(R.image.icons.overview.date_edit.name)
                                .renderingMode(.template)
                                .foregroundColor(R.color.primary.color())
                        })
                        .frame(size: 40)
                }
            }
            OverviewHeaderValuesView(controls: controls)
        }
        .onAppear(perform: {
            DispatchQueue.main.asyncAfter(deadline: .now() + .milliseconds(500)) {
                // See comment about simulator issues in the progress view.
                self.beginAnimation = !systemInformationService.isSimulator
            }
        })
    }
}

struct OverviewHeaderView_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            OverviewHeaderView(
                monthsIntoPregnancy: 5,
                numberOfFetuses: 1,
                title: "Title",
                subtitle: "Subtitle",
                controls: [
                    OverviewHeaderControl(
                        title: "Test 1",
                        type: .value(nil),
                        minWidth: 70
                    ),
                    OverviewHeaderControl(
                        title: "Test 2",
                        type: .textAction("Title", { }),
                        minWidth: 70,
                        prefixSpace: true
                    )
                ], titleButtonAction: nil
            )
        }
        .padding()
    }
}
