// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OverviewWaitingHeaderView: View {
    let monthsIntoPregnancy: Double?
    let dueDate: Date?
    let month: Int
    let week: Int
    let gestationAge: String
    let trimester: Int
    let numberOfFetuses: Int
    @Binding var didGiveBirthButtonPressed: Bool
    @Binding var editPregnancyButtonPressed: Bool

    private var dueDateString: String {
        guard let dueDate: Date = dueDate else {
            return Localizable.common_missing_data()
        }
        return OverviewDateFormatter.string(from: dueDate)
    }

    var body: some View {
        OverviewHeaderView(
            monthsIntoPregnancy: monthsIntoPregnancy,
            numberOfFetuses: numberOfFetuses,
            title: Localizable.overview_your_pregnancy_due_date(dueDateString),
            subtitle: nil,
            controls: [
                OverviewHeaderControl(
                    title: Localizable.overview_week_title(),
                    type: .dualValue("\(week.description).", gestationAge),
                    minWidth: Metrics.Sizes.overviewHeaderWeekWidth
                ),
                OverviewHeaderControl(
                    title: Localizable.overview_month_title(),
                    type: .value("\(month.description)."),
                    minWidth: Metrics.Sizes.overviewHeaderDefaultValueWidth
                ),
                OverviewHeaderControl(
                    title: Localizable.overview_trimester_title(),
                    type: .value("\(trimester.description)."),
                    minWidth: Metrics.Sizes.overviewHeaderDefaultValueWidth
                ),
                week >= 36 ?
                    OverviewHeaderControl(
                        title: nil,
                        type: .textAction(
                            Localizable.overview_did_give_birth_button_title(),
                            { didGiveBirthButtonPressed = true } //swiftlint:disable:this opening_brace
                        ),
                        minWidth: Metrics.Sizes.overviewHeaderGaveBirthButtonWidth
                    )
                    : nil
            ].compactMap({ $0 }),
            titleButtonAction: { editPregnancyButtonPressed = true }
        )
    }
}

struct OverviewWaitingHeaderView_Previews: PreviewProvider {
    static var previews: some View {
        ScrollView {
            VStack {
                OverviewWaitingHeaderView(
                    monthsIntoPregnancy: 3.64,
                    dueDate: Date(),
                    month: 4,
                    week: 19,
                    gestationAge: "(18+5)",
                    trimester: 2,
                    numberOfFetuses: 1,
                    didGiveBirthButtonPressed: .constant(false),
                    editPregnancyButtonPressed: .constant(false)
                )
                OverviewWaitingHeaderView(
                    monthsIntoPregnancy: 8.64,
                    dueDate: Date(),
                    month: 9,
                    week: 37,
                    gestationAge: "38+5",
                    trimester: 4,
                    numberOfFetuses: 2,
                    didGiveBirthButtonPressed: .constant(false),
                    editPregnancyButtonPressed: .constant(false)
                )
            }
            .padding()
        }
    }
}
