// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OverviewWelcomeHeaderView: View {
    let title: String
    let subtitle: String
    let buttonAction: (() -> Void)?

    var body: some View {
        HStack {
            VStack(alignment: .leading) {
                Text(title)
                    .applyTextStyle(fontStyle: .body)
                Text(subtitle)
                    .applyTextStyle(fontStyle: .hero)
                    .minimumScaleFactor(0.7)
                    .lineLimit(1)
            }
            Spacer(minLength: 16)
            Button(
                action: buttonAction ?? {},
                label: {
                    Image(R.image.icons.overview.date_add.name)
                        .renderingMode(.template)
                        .foregroundColor(R.color.primary.color())
                })
                .frame(size: 40)
                .background(
                    Circle()
                        .fill(R.color.cardBackground.color())
                        .applyDefaultShadow()
                )
                .accessibility(label: Text(Localizable.overview_pick_pregnancy_title()))
                .hidden(buttonAction == nil)

        }
    }
}

struct OverviewWelcomeHeaderView_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            OverviewWelcomeHeaderView(
                title: "Din graviditet",
                subtitle: "Overblik",
                buttonAction: { }
            )
            OverviewWelcomeHeaderView(
                title: "Hej og velkommen",
                subtitle: "Thomas Croissant Kalhøj Clemensen",
                buttonAction: nil
            )
        }

    }
}
