// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import SharedServices
import Rswift

final class OnboardingStepsFactory {
    @DI private static var systemInformation: SystemInformationService

    private static let screenHasRoundedCorners: Bool = systemInformation.screenHasRoundedCorners

    private static var overviewImage: ImageResource {
        screenHasRoundedCorners ? R.image.onboarding.overview : R.image.onboarding.scaled.overview
    }

    private static var appointmentsImage: ImageResource {
        screenHasRoundedCorners ? R.image.onboarding.appointments : R.image.onboarding.scaled.appointments
    }

    private static var knowledgeImage: ImageResource {
        screenHasRoundedCorners ? R.image.onboarding.knowledge : R.image.onboarding.scaled.knowledge
    }

    static var steps: [OnboardingStepView.ViewModel] {
        [
            OnboardingStepView.ViewModel(
                title: Localizable.onboarding_overview_title(),
                subtitle: Localizable.onboarding_overview_text(),
                image: overviewImage
            ),
            OnboardingStepView.ViewModel(
                title: Localizable.onboarding_appointments_title(),
                subtitle: Localizable.onboarding_appointments_text(),
                image: appointmentsImage
            ),
            OnboardingStepView.ViewModel(
                title: Localizable.onboarding_knowledge_title(),
                subtitle: Localizable.onboarding_knowledge_text(),
                image: knowledgeImage
            )
        ]
    }
}
