// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import UIKit
import SwiftUI

struct CustomButton : View {
    @Environment(\.isEnabled) private var isEnabled: Bool

    let title: String
    let foregroundColor: Color
    let backgroundColor: Color
    let action: () -> Void
    var body: some View {
        Button(action: action, label: {
            Text(title)
                .applyTextStyle(fontStyle: .button, textColor: foregroundColor)
                .multilineTextAlignment(.center)
                .frame(maxWidth: .infinity)
                .frame(height: Metrics.Sizes.buttonHeight)
                .padding(.horizontal)
                .background(backgroundColor)
                .cornerRadius(8.0)
        })
        .buttonStyle(CustomButtonStyle(isEnabled: isEnabled))
    }
}

private struct CustomButtonStyle: ButtonStyle {
    let isEnabled: Bool

    func makeBody(configuration: Self.Configuration) -> some View {
        configuration.label
            .opacity(currentOpacity(configuration))
    }

    private func currentOpacity(_ configuration: Self.Configuration) -> Double {
        let opacity: Double
        if !isEnabled {
            opacity = 0.4
        } else if configuration.isPressed {
            opacity = 0.7
        } else {
            opacity = 1.0
        }
        return opacity
    }
}

struct CustomButton_Previews: PreviewProvider {
    static var previews: some View {
        VStack(spacing: 20) {
            CustomButton(
                title: "Hello",
                foregroundColor: Color.white,
                backgroundColor: R.color.primary.color(),
                action: { }
            )
            CustomButton(
                title: "Hello Hello!",
                foregroundColor: Color.white,
                backgroundColor: R.color.primary.color(),
                action: { }
            )
            .disabled(true)
            CustomButton(
                title: (0...15).map({ _ in "test "}).joined(),
                foregroundColor: .black,
                backgroundColor: .yellow,
                action: { }
            )
        }
        .padding()
    }
}
