// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI
import GMAppData

struct FoldableTextCardView<AccessoryView: View>: View {
    let title: String
    let titleAccessory: AccessoryView // Use `EmptyView` for none
    let text: String
    let infoText: String?
    let footerText: String?

    @State private var isExpanded = false
    @State private var isTruncated = false

    var body: some View {
        ExpandableCardView(
            isExpanded: $isExpanded,
            showFoldingButton: isTruncated,
            isFoldingButtonEnabled: true) {
            HStack(spacing: 0) {
                VStack(alignment: .leading) {
                    if let infoText = infoText {
                        Text(infoText)
                            .applyTextStyle(fontStyle: .info, textColor: R.color.greyText.color())
                            .padding(.bottom, 8)
                    }

                    HStack {
                        titleAccessory
                        Text(title)
                            .applyTextStyle(fontStyle: .h4)
                    }

                    ExpandableText(
                        text: text,
                        maxNumberOfLines: 2,
                        isTruncated: $isTruncated,
                        isExpanded: $isExpanded
                    )

                    if let footerText = footerText {
                        Text(footerText)
                            .applyTextStyle(fontStyle: .info, textColor: R.color.greyText.color())
                            .padding(.top, 4)
                    }
                }
                Spacer(minLength: 0)
            }
            .frame(maxWidth: .infinity)
        }
    }
}

struct FoldableTextCardView_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            FoldableTextCardView(
                title: "title",
                titleAccessory: Circle().fill(Color.blue).frame(size: 15),
                text: .loremIpsum(.small),
                infoText: "Test",
                footerText: "My footer"
            )
            FoldableTextCardView(
                title: "title",
                titleAccessory: EmptyView(),
                text: "Short text",
                infoText: "Test 2",
                footerText: .loremIpsum(.small)
            )
            FoldableTextCardView(
                title: "title",
                titleAccessory: EmptyView(),
                text: "Short text",
                infoText: nil,
                footerText: nil
            )

        }
    }
}
