// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct FeedbackInvitationView: View {
    @Binding var didPressButton: Bool

    var body: some View {
        VStack {
            VStack {
                Text(Localizable.feedback_invitation_title())
                    .applyTextStyle(fontStyle: .h3, textColor: .white)
                    .multilineTextAlignment(.center)
                CustomButton(
                    title: Localizable.feedback_invitation_button(),
                    foregroundColor: Color.white,
                    backgroundColor: R.color.infoButton.color(),
                    action: {
                        didPressButton = true
                    }
                )
                .padding(.vertical)
                Text(Localizable.feedback_invitation_description())
                    .applyTextStyle(fontStyle: .info, textColor: .white)
                    .multilineTextAlignment(.center)
            }
            .padding()
        }
        .frame(minHeight: 170)
        .background(
            Image(R.image.feedback_invitation_background.name)
                .resizable()
                .aspectRatio(contentMode: .fill)
                .accessibility(hidden: true)
        )
        .clipShape(RoundedRectangle(cornerRadius: Metrics.Sizes.cardCornerRadius))
        .applyDefaultCardShadow()
    }
}

struct FeedbackInvitationView_Previews: PreviewProvider {
    static var previews: some View {
        VStack {
            FeedbackInvitationView(
                didPressButton: .constant(false)
            )
            .padding()
            Spacer()
        }
    }
}
