// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import GMAppData
import XCTest
@testable import MinGraviditet

final class ActivityTests: XCTestCase {
    
    func testDateString() {
        let date = Date()

        let plannedActivity = Self.activity(scheduledString: "1234+4", date: date, status: .planned)
        XCTAssertEqual(plannedActivity.dateString, "1234+4")

        let plannedActivity2 = Self.activity(scheduledString: nil, date: date, status: .planned)
        XCTAssertEqual(plannedActivity2.dateString, Activity.dateFormatter.string(from: date))

        let plannedActivity3 = Self.activity(scheduledString: nil, date: nil, status: .planned)
        XCTAssertEqual(plannedActivity3.dateString, "-")

        let finishedActivity = Self.activity(scheduledString: "4321+1", date: date, status: .finished)
        XCTAssertEqual(finishedActivity.dateString, Activity.dateFormatter.string(from: date))

        let finishedActivity2 = Self.activity(scheduledString: "4321+1", date: nil, status: .finished)
        XCTAssertEqual(finishedActivity2.dateString, "4321+1")

        let finishedActivity3 = Self.activity(scheduledString: nil, date: nil, status: .finished)
        XCTAssertEqual(finishedActivity3.dateString, "-")
    }

    func testIsPlannedOrExpected() {
        let finishedActivity = Self.activity(scheduledString: nil, date: nil, status: .finished)
        XCTAssertFalse(finishedActivity.isPlannedOrExpected)

        let cancelledActivity = Self.activity(scheduledString: nil, date: nil, status: .cancelled)
        XCTAssertFalse(cancelledActivity.isPlannedOrExpected)

        let plannedActivity = Self.activity(scheduledString: nil, date: nil, status: .planned)
        XCTAssertTrue(plannedActivity.isPlannedOrExpected)

        let expectedActivity = Self.activity(scheduledString: nil, date: nil, status: .expected)
        XCTAssertTrue(expectedActivity.isPlannedOrExpected)
    }

    func testIsSortDateInFuture() {
        let pastActivity = Self.activity(scheduledString: nil, date: Date().addingTimeInterval(-1), status: .finished)
        XCTAssertFalse(pastActivity.isSortDateInFuture)

        let futureActivity = Self.activity(scheduledString: nil, date: Date().addingTimeInterval(1), status: .finished)
        XCTAssertTrue(futureActivity.isSortDateInFuture)

        let nowActivity = Self.activity(scheduledString: nil, date: Date(), status: .finished)
        XCTAssertFalse(nowActivity.isSortDateInFuture)
    }

    private static func activity(scheduledString: String?, date: Date?, status: Activity.Status) -> Activity {
        Activity(
            practitioner: nil,
            location: nil,
            scheduledString: scheduledString,
            plannedTime: nil,
            conductedTime: date,
            status: status,
            ownership: nil,
            title: "Test",
            description: nil,
            reference: nil,
            code: nil,
            kind: nil,
            id: nil,
            careplanId: "1",
            note: nil,
            observations: nil,
            sortDate: date
        )
    }
}
