// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest

class RegisterUserUITest: XCTestCase {

    override func setUpWithError() throws {
        continueAfterFailure = false
        XCUIApplication.launchWithEnvironmentVariable()
    }

    override func tearDownWithError() throws {
        // Put teardown code here. This method is called after the invocation of each test method in the class.
    }

    func testRegisterUserWithNemIDAndLogOutAndIn() throws {

        let app = XCUIApplication()

        // Login with NemID
        app.buttons["login_nemid"].tap()

        goThroughRegisterFlowFromConsent(app)

        // Try all tabs in tab bar
        let tabBar = app.tabBars["tab_bar"]
        tabBar.buttons["tabbar_appointments"].tap()
        tabBar.buttons["tabbar_overview"].tap()
        tabBar.buttons["tabbar_knowledge"].tap()
        tabBar.buttons["tabbar_journal"].tap()
        tabBar.buttons["tabbar_more"].tap()

        // Logout
        app.buttons["settings"].tap()
        app.buttons["log_out"].tap()

        // Login
        for _ in 0..<4 {
            app.buttons["1"].tap() // pin code: 1111
        }

        // Tap on a tab again to verify you are logged in
        tabBar.buttons["tabbar_appointments"].tap()
    }

    func testRegisterWithoutNemID() {
        let app = XCUIApplication()

        // Log in without NemID
        app.buttons["login_without_nemid"].tap()

        // Tap on "Kategori 1"
        app.buttons["Kategori 1"].tap()
    }

    func testRegisterAfterLoggingInWithoutNemID() {
        let app = XCUIApplication()

        // Log in without NemID
        app.buttons["login_without_nemid"].tap()

        // Wait for article content to be present
        let exists = app.buttons["Kategori 1"].waitForExistence(timeout: 5.0)
        if !exists {
            XCTFail("Failed to load mock article content.")
        }

        // Login with NemID
        app.buttons["login_nemid"].tap()

        goThroughRegisterFlowFromConsent(app)

        let tabBar = app.tabBars["tab_bar"]
        let tabBarExists = tabBar.waitForExistence(timeout: 5.0)
        XCTAssertTrue(tabBarExists)
    }

    private func goThroughRegisterFlowFromConsent(_ app: XCUIApplication) {
        let acceptButton = app.buttons["consent_accept"]
        let exists = acceptButton.waitForExistence(timeout: 30.0)
        if !exists {
            XCTFail("Consent button never appeared.")
        }

        // Accept terms
        expectation(for: NSPredicate(value: acceptButton.isEnabled), evaluatedWith: nil, handler: nil)
        waitForExpectations(timeout: 10.0, handler: nil)
        acceptButton.tap()

        // Press OK button in mock web view
        let okMockButton = app.webViews.buttons["Ok"]
        let okButtonExists = okMockButton.waitForExistence(timeout: 10.0)
        if !okButtonExists {
            XCTFail("Ok button on web view never appeared.")
        }
        okMockButton.tap()

        for _ in 0..<4 {
            app.buttons["1"].tap() // pin code: 1111
        }

        let alert = app.alerts.firstMatch
        let alertExists = alert.waitForExistence(timeout: 3.0)
        if alertExists {
            alert.buttons["Brug ikke"].tap()
        }
    }

}
