// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import XCTest
import ErrorData
import HTTPMockHelpers
import GMAppData
@testable import ConfigurationServices

final class ConfigurationServiceImplTests: ConfigurationURLSessionMockTestCase {
    let configurationService = ConfigurationServiceImpl()

    let maternityId = UUID().uuidString

    func testChecklists() {
        let testData = [
            "id-1",
            "id-2"
        ]
        let url = URL(string: "\(Self.config.configurationBaseUrl)/checklist")!
        URLSessionStubResults.resultsForUrls[url] = .dataResponse(
            data: try! JSONEncoder.iso8601().encode(testData),
            response:  URLSessionStubResponses.response(url: url)!
        )

        let expect = XCTestExpectation()
        configurationService.fetchChecklists(maternityId: maternityId)
            .sink(
                receiveCompletion: { self.handleSubscriberCompletion($0, expectation: expect) },
                receiveValue: { checklists in
                    XCTAssertEqual(2, checklists.count)
                }
            ).store(in: &cancelBag)
        wait(for: [expect], timeout: 1.0)
    }

    func testUpdateChecklistItem() {
        let url = URL(string: "\(Self.config.configurationBaseUrl)/checklist/id-1")!
        URLSessionStubResults.resultsForUrls[url] = .dataResponse(
            data: "".data(using: .utf8)!,
            response:  URLSessionStubResponses.response(url: url)!
        )
        let expect = XCTestExpectation()
        configurationService.updateChecklistItem(maternityId: maternityId, itemId: "id-1", isChecked: true)
            .sink(
                receiveCompletion: { self.handleSubscriberCompletion($0, expectation: expect) },
                receiveValue: { _ in }
            ).store(in: &cancelBag)
        wait(for: [expect], timeout: 1.0)
    }

    func testDeleteAllData() {
        let url = URL(string: "\(Self.config.configurationBaseUrl)")!
        URLSessionStubResults.resultsForUrls[url] = .dataResponse(
            data: "".data(using: .utf8)!,
            response:  URLSessionStubResponses.response(url: url)!
        )
        let expect = XCTestExpectation()
        configurationService.deleteAllData()
            .sink(
                receiveCompletion: { self.handleSubscriberCompletion($0, expectation: expect) },
                receiveValue: { _ in }
            ).store(in: &cancelBag)
        wait(for: [expect], timeout: 1.0)
    }
}
